@@ -1,5 +1,5 @@
 package Catalyst::Plugin::Session::State::Cookie;
-use base qw/Catalyst::Plugin::Session::State/;
+use base qw/Catalyst::Plugin::Session::State Class::Accessor::Fast/;
 
 use strict;
 use warnings;
@@ -7,7 +7,9 @@ use warnings;
 use NEXT;
 use Catalyst::Utils ();
 
-our $VERSION = "0.06";
+our $VERSION = "0.08";
+
+BEGIN { __PACKAGE__->mk_accessors(qw/_deleted_session_id/) }
 
 sub setup_session {
     my $c = shift;
@@ -111,7 +113,7 @@ sub get_session_cookie {
 sub get_session_id {
     my $c = shift;
 
-    if ( my $cookie = $c->get_session_cookie  ) { 
+    if ( !$c->_deleted_session_id and my $cookie = $c->get_session_cookie ) { 
         my $sid = $cookie->value;
         $c->log->debug(qq/Found sessionid "$sid" in cookie/) if $c->debug;
         return $sid if $sid;
@@ -122,6 +124,8 @@ sub get_session_id {
 
 sub delete_session_id {
     my ( $c, $sid ) = @_;
+    
+    $c->_deleted_session_id(1); # to prevent get_session_id from returning it
 
     $c->update_session_cookie( $c->make_session_cookie( $sid, expires => 0 ) );
 
@@ -161,6 +165,22 @@ Returns a hash reference with the default values for new cookies.
 
 Sets the cookie based on C<cookie_name> in the response object.
 
+=item calc_expiry
+
+=item calculate_session_cookie_expires
+
+=item cookie_is_rejecting
+
+=item delete_session_id
+
+=item extend_session_id
+
+=item get_session_cookie
+
+=item get_session_id
+
+=item set_session_id
+
 =back
 
 =head1 EXTENDED METHODS
@@ -230,14 +250,18 @@ L<Catalyst>, L<Catalyst::Plugin::Session>.
 
 =head1 AUTHORS
 
+Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
+
+=head1 CONTRIBUTORS
+
 This module is derived from L<Catalyst::Plugin::Session::FastMmap> code, and
 has been heavily modified since.
 
 Andrew Ford
 Andy Grundman
 Christian Hansen
-Yuval Kogman, C<nothingmuch@woobling.org>
 Marcus Ramberg
+Jonathan Rockway E<lt>jrockway@cpan.orgE<gt>
 Sebastian Riedel
 
 =head1 COPYRIGHT
